# PermissionDto


## Enum

* `PROJECT_COLON_CONFIGURE` (value: `'project:configure'`)

* `PROJECT_COLON_WRITE` (value: `'project:write'`)

* `PROJECT_COLON_COMMENT` (value: `'project:comment'`)

* `PROJECT_COLON_READ` (value: `'project:read'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


